version 11.2

*adjust working directory!

use replication.dta, clear

*Compute Model1
xtset party year
xtgls chrile incl chpmean ichpmean chcmean ichcmean i.party, panels(heteroscedastic) corr(ar) noconstant force

matrix v = e(V) // get vcv-matrix
drop _all
set obs 4
gen n = _n
gen hi = .
gen lo = .
gen mean =.

local pos1 = 2 
local pos2 = 3
local pos3 = 4
local pos4 = 5

forvalues a = 0/1 {
	*compute point estimates for mean supporter change with and without condition
	local pmean = _b[chpmean]+ (`a' * _b[ichpmean])
	
	*compute corresponding standard error
	local se_pmean = sqrt(v[`pos1',`pos1']+((`a'^2)*v[`pos2',`pos2'])+(2*`a'*v[`pos2',`pos1']))
	local in_p = `a' +1
	
	*compute 95% confidence intervals
	replace lo = `pmean' - (1.96*`se_pmean') in `in_p'
	replace hi = `pmean' + (1.96*`se_pmean') in `in_p'
	replace mean = `pmean' in `in_p'
	
	*repeat these steps for mean voter change
	local cmean = _b[chcmean]+ (`a' * _b[ichcmean])
	local se_cmean = sqrt(v[`pos3',`pos3']+((`a'^2)*v[`pos4',`pos4'])+(2*`a'*v[`pos4',`pos3']))
	local in_c = `a' +3
	
	replace lo = `cmean' - (1.96*`se_cmean') in `in_c'
	replace hi = `cmean' + (1.96*`se_cmean') in `in_c'
	replace mean = `cmean' in `in_c'
	

}
gen type ="gls"
save figure1_gls, replace

*repeat all of these steps with the FE model

use replication.dta, clear

xtset party year
xtreg chrile lchrile incl chpmean ichpmean chcmean ichcmean, fe robust
matrix v = e(V)
drop _all
set obs 4
gen n = _n
gen hi = .
gen lo = .
gen mean =.

local pos1 = 3 
local pos2 = 4
local pos3 = 5
local pos4 = 6

forvalues a = 0/1 {
	local pmean = _b[chpmean]+ (`a' * _b[ichpmean])
	local se_pmean = sqrt(v[`pos1',`pos1']+((`a'^2)*v[`pos2',`pos2'])+(2*`a'*v[`pos2',`pos1']))
	local in_p = `a' +1

	replace lo = `pmean' - (1.96*`se_pmean') in `in_p'
	replace hi = `pmean' + (1.96*`se_pmean') in `in_p'
	replace mean = `pmean' in `in_p'
	
	local cmean = _b[chcmean]+ (`a' * _b[ichcmean])
	local se_cmean = sqrt(v[`pos3',`pos3']+((`a'^2)*v[`pos4',`pos4'])+(2*`a'*v[`pos4',`pos3']))
	local in_c = `a' +3
	
	replace lo = `cmean' - (1.96*`se_cmean') in `in_c'
	replace hi = `cmean' + (1.96*`se_cmean') in `in_c'
	replace mean = `cmean' in `in_c'
	

}
replace n = n + .2
append using figure1_gls.dta

*Make Graphs
#delimit ;
graph twoway 
rcap lo hi n if n>=1 & n<3, lwidth(medium) lcolor(black)  vertical ||
scatter mean n if n==1|n==2, msymbol(O) mfcolor(black) msize(medium) mcolor(black) ||
scatter mean n if ((n>1&n<2)|(n>2&n<3)), msymbol(O) mfcolor(white) msize(medium) mcolor(black)||,
	yline(0, lcolor(black) lwidth(vvthin))
	xlabel(1.1 "Exclusive" 2.1 "Inclusive")
	xtitle("")
	legend(off)
	saving(pmean_1, replace)
	graphregion(color(white))
	plotregion(color(white))
	ylabel(, nogrid)
	xscale(range(0.5 2.5))
	title(Shift Mean Supporter, color(black))
	;
#delimit cr;

preserve
drop if n <3
replace n = n -2


#delimit ;
graph twoway 
rcap lo hi n if n>=1 & n<3, lwidth(medium) lcolor(black)  vertical ||
scatter mean n if n==1|n==2, msymbol(O) mfcolor(black) msize(medium) mcolor(black) ||
scatter mean n if ((n>1&n<2)|(n>2&n<3)), msymbol(O) mfcolor(white) msize(medium) mcolor(black)||,
	yline(0, lcolor(black) lwidth(vvthin))
	xlabel(1.1 "Exclusive" 2.1 "Inclusive")
	xtitle("")
	legend(off)
	saving(cmean_1, replace)
	graphregion(color(white))
	plotregion(color(white))
	ylabel(, nogrid)
	xscale(range(0.5 2.5))
	title(Shift Mean Voter, color(black))
	;
#delimit cr;
restore

*Combine Graphs
#delimit ;
graph combine pmean_1.gph cmean_1.gph ,
commonscheme
cols(2)
graphregion(color(white))
plotregion(color(white))
l1title(Marginal Effect on Change in Party Position)
saving(figure1.gph, replace)
b2title(Inclusiveness)
ycommon
xcommon
;
#delimit cr;

erase pmean_1.gph
erase cmean_1.gph
erase figure1_gls.dta




